@@ -8,6 +8,9 @@ import logging
 import ssl
 import vcr
 
+# This library used by aiohttp 3.8 needs its logging turned down
+logging.getLogger("charset_normalizer").setLevel(logging.ERROR)
+
 class HttpClient(object):
     """Helper class to simplify HTTP operations on an open session."""
     def __init__(self, url, verify_ssl=True, username=None, password=None,
